@@ -13,7 +13,7 @@ def action(*args, **params):
         async def decorator(*args, **kwargs):
             return await func(*args, **kwargs)
         decorator.action = ImmutableDTO.fromdict({
-            'name': func.__name__,
+            'name': params.get('name') or func.__name__,
             'path': str.replace(func.__name__, '_', '-'),
             'methods': ['GET'],
             **params
