@@ -6,7 +6,7 @@ from fastapi.testclient import TestClient
 
 from unimatrix.ext import webapi
 from .. import ResourceEndpointSet
-from .. import __boot__ as boot
+from .. import __unimatrix__ as boot
 from ..asgi import Application
 
 
@@ -20,7 +20,7 @@ class SubresourceTestCase(unittest.TestCase):
             pass
 
         @webapi.action(detail=True)
-        async def detail_action(self):
+        async def detail_action(self, **kwargs):
             pass
 
     def setUp(self):
